==> molsimplify-1.2.2-np19py27_2.tar.bz2: lib/python2.7/site-packages/molSimplify/simulate_cli.py <==
import os
import subprocess
from datetime import datetime
start = datetime.now()
#subprocess.call(["python",'main.py','-slab_gen',
#                 '-cif_path', 'Unitcells/gold.cif','-duplication_vector','[4,2,2]'])
# subprocess.call(["python",'ptcotest.py','-slab_gen','-cif_path','data/gold.cif',
#                  '-slab_size','15,15,5','-align_dist','1.89','-duplication_vector','2,2,2'])
#subprocess.call(["python",'ptcotest.py','-slab_gen','-cif_path','data/gold.cif',
#                 '-align_dist','1.89','-duplication_vector','[2,2,2]','-slab_size','[15,15,5]',
#                 '-align_distance_method','custom','miller_index','[1,1,1]','-align_method'])


#subprocess.call(["python",'main.py','-slab_gen','-cif_path','Unitcells/gold.cif',
#                 '-align_dist','2.7','-slab_size','[15,15,5]','-align_distance_method',
#                 'custom','-miller_index','[1,1,1]','-align_method','alignpair',
#                 '-place_on_slab','-target_molecule','/home/jp/Runs/copo.xyz','-surface_atom_type','Au',
#                 '-object_align','Co','-control_angle','40','-angle_control_partner','2',
#                 '-angle_surface_axis','[1,1]'])

#subprocess.call(["python",'main.py','-slab_gen','-cif_path','Unitcells/gold.cif',
#                 '-slab_size','[15,15,5]','-align_distance_method',
#                 'chemisorption','-miller_index','[1,1,1]','-align_method','alignpair',
#                 '-place_on_slab','-target_molecule','/home/jp/Runs/copo.xyz','-surface_atom_type','Au',
#                 '-object_align','Co','-control_angle','40','-angle_control_partner','2',
#                 '-angle_surface_axis','[1,1]'])

#subprocess.call(["python",'main.py','-slab_gen','-cif_path','Unitcells/gold.cif',
#                 '-slab_size','[15,15,5]',
#                 '-miller_index','[1,1,1]'])
#subprocess.call(["python",'main.py','-slab_gen','-cif_path','Unitcells/gold.cif',
#                 '-duplication_vector','[3,3,2]','-miller_index','[1,1,1]'])
#subprocess.call(["python",'main.py','-slab_gen','-cif_path','Unitcells/gold.cif',
#                 '-align_dist','1.89','-slab_size','[15,15,5]','-align_distance_method',
#                 'custom','-align_method','alignpair',
#                 '-place_on_slab','-target_molecule','/home/jp/Runs/copo.xyz','-surface_atom_type','Au',
 #                '-object_align','Co','-control_angle','90','-angle_control_partner','2',
  #               '-angle_surface_axis','[1,1]'])
#subprocess.call(["python",'main.py','-slab_gen','-cif_path','Unitcells/anatase_tio2.cif',
#                 '-slab_size','[12,12,8]','-miller_index','[1,1,0]','-place_on_slab','-target_molecule','/home/jp/Runs/mo5.xyz',
#                 '-align_method','alignpair','-surface_atom_type','Ti','-num_surface_atoms','4',
#                 '-object_align','2,3,4,5','-align_dist','2.5'])
#subprocess.call(["python",'main.py','-slab_gen','-cif_path','Unitcells/anatase_tio2.cif',
#                 '-slab_size','[12,12,8]','-place_on_slab','-miller_index','[1,0,1]','-target_molecule','/home/jp/Runs/mo5.xyz',
#                 '-align_method','alignpair','-surface_atom_type','Ti','-num_surface_atoms','4',
#                 '-object_align','2,3,4,5','-align_dist','2.5'])
#subprocess.call(["python",'main.py','-slab_gen','-cif_path','Unitcells/anatase_tio2.cif',
#                 '-slab_size','[12,12,8]','-miller_index','[1,0,1]','-target_molecule','/home/jp/Runs/mo5.xyz',
#                 '-align_method','alignpair','-surface_atom_type','Ti','-num_surface_atoms','4',
#                 '-object_align','2,3,4,5','-align_dist','2.5'])
#
#subprocess.call(["python",'-m','molSimplify.__main__','-slab_gen','-cif_path','Unitcells/anatase_tio2.cif',
#                 '-slab_size','[9,9,9]','-place_on_slab','-target_molecule','/home/jp/Runs/co.xyz',
#                 '-align_method','alignpair','-surface_atom_type','Ti','-num_surface_atoms','1',
#                 '-object_align','C','-align_dist','2.5'])
#
subprocess.call(["python","-m",'molSimplify.__main__','-slab_gen','-cif_path','molSimplify/Unitcells/anatase_tio2.cif',
                 '-slab_size','[9,9,9]','-miller_index','[1,0,0]','-freeze','1'])



#
#subprocess.call(["python","main.py","-core","Fe","-coord",'6',"-lig","acac,water","-ligocc",'2,2',
#                 '-geometry','oct','-distort','0','checkdirb','True','-ligalign','False',
#3                 '-keepHs','False','-bcharge','0','-rundir','/home/jp/Runs/CLI',
#                 '-oxstate','0','-spin','1'])
print(datetime.now() - start)

==> molsimplify-1.2.3-np19py27_2.tar.bz2: lib/python2.7/site-packages/molSimplify/simulate_cli.py <==
import os
import subprocess
from datetime import datetime
start = datetime.now()
#subprocess.call(["python",'main.py','-slab_gen',
#                 '-cif_path', 'Unitcells/gold.cif','-duplication_vector','[4,2,2]'])
# subprocess.call(["python",'ptcotest.py','-slab_gen','-cif_path','data/gold.cif',
#                  '-slab_size','15,15,5','-align_dist','1.89','-duplication_vector','2,2,2'])
#subprocess.call(["python",'ptcotest.py','-slab_gen','-cif_path','data/gold.cif',
#                 '-align_dist','1.89','-duplication_vector','[2,2,2]','-slab_size','[15,15,5]',
#                 '-align_distance_method','custom','miller_index','[1,1,1]','-align_method'])


#subprocess.call(["python",'main.py','-slab_gen','-cif_path','Unitcells/gold.cif',
#                 '-align_dist','2.7','-slab_size','[15,15,5]','-align_distance_method',
#                 'custom','-miller_index','[1,1,1]','-align_method','alignpair',
#                 '-place_on_slab','-target_molecule','/home/jp/Runs/copo.xyz','-surface_atom_type','Au',
#                 '-object_align','Co','-control_angle','40','-angle_control_partner','2',
#                 '-angle_surface_axis','[1,1]'])

#subprocess.call(["python",'main.py','-slab_gen','-cif_path','Unitcells/gold.cif',
#                 '-slab_size','[15,15,5]','-align_distance_method',
#                 'chemisorption','-miller_index','[1,1,1]','-align_method','alignpair',
#                 '-place_on_slab','-target_molecule','/home/jp/Runs/copo.xyz','-surface_atom_type','Au',
#                 '-object_align','Co','-control_angle','40','-angle_control_partner','2',
#                 '-angle_surface_axis','[1,1]'])

#subprocess.call(["python",'main.py','-slab_gen','-cif_path','Unitcells/gold.cif',
#                 '-slab_size','[15,15,5]',
#                 '-miller_index','[1,1,1]'])
#subprocess.call(["python",'main.py','-slab_gen','-cif_path','Unitcells/gold.cif',
#                 '-duplication_vector','[3,3,2]','-miller_index','[1,1,1]'])
#subprocess.call(["python",'main.py','-slab_gen','-cif_path','Unitcells/gold.cif',
#                 '-align_dist','1.89','-slab_size','[15,15,5]','-align_distance_method',
#                 'custom','-align_method','alignpair',
#                 '-place_on_slab','-target_molecule','/home/jp/Runs/copo.xyz','-surface_atom_type','Au',
 #                '-object_align','Co','-control_angle','90','-angle_control_partner','2',
  #               '-angle_surface_axis','[1,1]'])
#subprocess.call(["python",'main.py','-slab_gen','-cif_path','Unitcells/anatase_tio2.cif',
#                 '-slab_size','[12,12,8]','-miller_index','[1,1,0]','-place_on_slab','-target_molecule','/home/jp/Runs/mo5.xyz',
#                 '-align_method','alignpair','-surface_atom_type','Ti','-num_surface_atoms','4',
#                 '-object_align','2,3,4,5','-align_dist','2.5'])
#subprocess.call(["python",'main.py','-slab_gen','-cif_path','Unitcells/anatase_tio2.cif',
#                 '-slab_size','[12,12,8]','-place_on_slab','-miller_index','[1,0,1]','-target_molecule','/home/jp/Runs/mo5.xyz',
#                 '-align_method','alignpair','-surface_atom_type','Ti','-num_surface_atoms','4',
#                 '-object_align','2,3,4,5','-align_dist','2.5'])
#subprocess.call(["python",'main.py','-slab_gen','-cif_path','Unitcells/anatase_tio2.cif',
#                 '-slab_size','[12,12,8]','-miller_index','[1,0,1]','-target_molecule','/home/jp/Runs/mo5.xyz',
#                 '-align_method','alignpair','-surface_atom_type','Ti','-num_surface_atoms','4',
#                 '-object_align','2,3,4,5','-align_dist','2.5'])
#
#subprocess.call(["python",'-m','molSimplify.__main__','-slab_gen','-cif_path','molSimplify/Unitcells/anatase_tio2.cif',
#                 '-slab_size','[9,9,9]','-place_on_slab','-target_molecule','/home/jp/Runs/co.xyz',
#                 '-align_method','alignpair','-surface_atom_ind','39','-num_surface_atoms','1',
#                 '-object_align','C','-align_dist','0.5','-shave_extra_layers','1'])
#
subprocess.call(["python",'-m','molSimplify.__main__','-slab_gen','-cif_path','/home/jp/Dropbox/quartz/quartz.cif',
                 '-slab_size','[14,14,6]','-rundir /home/jp/Dropbox/quartz/\n','-debug','-align_method','alignpair', '-freeze', '4',
                 '-place_on_slab','-target_molecule','/home/jp/Dropbox/quartz/mol.xyz','-object_align', 'Mn','-expose_type','O',
                 '-align_dist','1.5','-shave_extra_layers','0','align_distance_method','custom','-surface_atom_type','O','-num_surface_atoms','2'])
#
#subprocess.call(["python","-m",'molSimplify.__main__','-slab_gen','-cif_path','molSimplify/Unitcells/anatase_tio2.cif',
#                 '-slab_size','[9,9,9]','-miller_index','[1,0,0]'])



#
#subprocess.call(["python","main.py","-core","Fe","-coord",'6',"-lig","acac,water","-ligocc",'2,2',
#                 '-geometry','oct','-distort','0','checkdirb','True','-ligalign','False',
#3                 '-keepHs','False','-bcharge','0','-rundir','/home/jp/Runs/CLI',
#                 '-oxstate','0','-spin','1'])
print(datetime.now() - start)
